Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(17)

Unified Diff: include/v8.h

Issue 1275683002: Rename "extras exports" to "extras binding" (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8.h
diff --git a/include/v8.h b/include/v8.h
index 1b65770d35e3fe98bf6f374b3df5b6c46b817ba6..19373a1398720ad1816df0dfd49ec5f8f88a86c0 100644
--- a/include/v8.h
+++ b/include/v8.h
@@ -6606,10 +6606,12 @@ class V8_EXPORT Context {
V8_INLINE Local<Value> GetEmbedderData(int index);
/**
* Gets the exports object used by V8 extras. Extra natives get a reference
* to this object and can use it to export functionality.
*/
- Local<Object> GetExtrasExportsObject();
+ Local<Object> GetExtrasBindingObject();
/**
* Sets the embedder data with the given index, growing the data as
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
@@ -6606,10 +6606,12 @@ class V8_EXPORT Context {
V8_INLINE Local<Value> GetEmbedderData(int index);
/**
- * Gets the exports object used by V8 extras. Extra natives get a reference
- * to this object and can use it to export functionality.
+ * Gets the binding object used by V8 extras. Extra natives get a reference
+ * to this object and can use it to "export" functionality by adding
+ * properties. Extra natives can also "import" functionality by accessing
+ * properties added by the embedder using the V8 API.
*/

Powered by Google App Engine
This is Rietveld 408576698